smartcard.reader.ReaderGroups.innerreadergroups

# ``smartcard`.`reader`.`ReaderGroups`.`innerreadergroups``

class documentation

`class innerreadergroups(ulist):`

Known subclasses: `smartcard.pcsc.PCSCReaderGroups.pcscinnerreadergroups`

View In Hierarchy

Smartcard readers groups private class.

The readergroups singleton manages the creation of the unique instance of this class.

Method | `__init__` | Retrieve and store list of reader groups
Method | `__iter__` | Undocumented
Method | `__onadditem__` | Called when a reader group is added.
Method | `__onremoveitem__` | Called when a reader group is added.
Method | `addreadergroup` | Add a reader group
Method | `addreadertogroup` | Add a reader to a reader group
Method | `getreadergroups` | Returns the list of smartcard reader groups.
Method | `next` | Undocumented
Method | `removereaderfromgroup` | Remove a reader from a reader group
Method | `removereadergroup` | Remove a reader group
Instance Variable | `unremovablegroups` | Undocumented

Inherited from `ulist`:

Method | `__add__` | Undocumented
Method | `__appendother__` | Append other to object.
Method | `__iadd__` | Undocumented
Method | `__radd__` | Undocumented
Method | `append` | Undocumented
Method | `insert` | Undocumented
Method | `pop` | Undocumented
Method | `remove` | Undocumented
Method | `__remove_duplicates` | Remove from other items already in list.

def __init__(self, initlist=None):
overrides `smartcard.ulist.ulist.__init__`
overridden in `smartcard.pcsc.PCSCReaderGroups.pcscinnerreadergroups`

Retrieve and store list of reader groups

def __iter__(self):

Undocumented

def __onadditem__(self, item):
overrides `smartcard.ulist.ulist.__onadditem__`

Called when a reader group is added.

def __onremoveitem__(self, item):
overrides `smartcard.ulist.ulist.__onremoveitem__`

Called when a reader group is added.

def addreadergroup(self, newgroup):
overridden in `smartcard.pcsc.PCSCReaderGroups.pcscinnerreadergroups`

Add a reader group

def addreadertogroup(self, readername, groupname):

Add a reader to a reader group

def getreadergroups(self):
overridden in `smartcard.pcsc.PCSCReaderGroups.pcscinnerreadergroups`

Returns the list of smartcard reader groups.

def next(self):

Undocumented

def removereaderfromgroup(self, readername, groupname):

Remove a reader from a reader group

def removereadergroup(self, group):
overridden in `smartcard.pcsc.PCSCReaderGroups.pcscinnerreadergroups`

Remove a reader group

unremovablegroups: `list` =
overridden in `smartcard.pcsc.PCSCReaderGroups.pcscinnerreadergroups`

Undocumented